@@ -18,7 +18,10 @@
 
 namespace vku {
 
-std::vector<std::pair<uint32_t, uint32_t>> custom_stype_info{};
+std::vector<std::pair<uint32_t, uint32_t>>& GetCustomStypeInfo() {
+    static std::vector<std::pair<uint32_t, uint32_t>> custom_stype_info{};
+    return custom_stype_info;
+}
 
 struct ASGeomKHRExtraData {
     ASGeomKHRExtraData(uint8_t* alloc, uint32_t primOffset, uint32_t primCount)
@@ -31,7 +34,12 @@ struct ASGeomKHRExtraData {
     uint32_t primitiveCount;
 };
 
-vku::concurrent::unordered_map<const safe_VkAccelerationStructureGeometryKHR*, ASGeomKHRExtraData*, 4> as_geom_khr_host_alloc;
+vku::concurrent::unordered_map<const safe_VkAccelerationStructureGeometryKHR*, ASGeomKHRExtraData*, 4>&
+GetAccelStructGeomHostAllocMap() {
+    static vku::concurrent::unordered_map<const safe_VkAccelerationStructureGeometryKHR*, ASGeomKHRExtraData*, 4>
+        as_geom_khr_host_alloc;
+    return as_geom_khr_host_alloc;
+}
 
 safe_VkAccelerationStructureGeometryKHR::safe_VkAccelerationStructureGeometryKHR(
     const VkAccelerationStructureGeometryKHR* in_struct, const bool is_host,
@@ -39,6 +47,13 @@ safe_VkAccelerationStructureGeometryKHR::safe_VkAccelerationStructureGeometryKHR
     : sType(in_struct->sType), geometryType(in_struct->geometryType), geometry(in_struct->geometry), flags(in_struct->flags) {
     if (copy_pnext) {
         pNext = SafePnextCopy(in_struct->pNext, copy_state);
+        if (geometryType == VK_GEOMETRY_TYPE_INSTANCES_KHR) {
+            geometry.instances.pNext = SafePnextCopy(in_struct->geometry.instances.pNext, copy_state);
+        } else if (geometryType == VK_GEOMETRY_TYPE_TRIANGLES_KHR) {
+            geometry.triangles.pNext = SafePnextCopy(in_struct->geometry.triangles.pNext, copy_state);
+        } else if (geometryType == VK_GEOMETRY_TYPE_AABBS_KHR) {
+            geometry.aabbs.pNext = SafePnextCopy(in_struct->geometry.aabbs.pNext, copy_state);
+        }
     }
     if (is_host && geometryType == VK_GEOMETRY_TYPE_INSTANCES_KHR) {
         if (geometry.instances.arrayOfPointers) {
@@ -57,7 +72,7 @@ safe_VkAccelerationStructureGeometryKHR::safe_VkAccelerationStructureGeometryKHR
                 ppInstances[i] = &pInstances[i];
             }
             geometry.instances.data.hostAddress = allocation;
-            as_geom_khr_host_alloc.insert(
+            GetAccelStructGeomHostAllocMap().insert(
                 this, new ASGeomKHRExtraData(allocation, build_range_info->primitiveOffset, build_range_info->primitiveCount));
         } else {
             const auto primitive_offset = build_range_info->primitiveOffset;
@@ -68,7 +83,7 @@ safe_VkAccelerationStructureGeometryKHR::safe_VkAccelerationStructureGeometryKHR
             memcpy(allocation + primitive_offset, host_address + primitive_offset,
                    primitive_count * sizeof(VkAccelerationStructureInstanceKHR));
             geometry.instances.data.hostAddress = allocation;
-            as_geom_khr_host_alloc.insert(
+            GetAccelStructGeomHostAllocMap().insert(
                 this, new ASGeomKHRExtraData(allocation, build_range_info->primitiveOffset, build_range_info->primitiveCount));
         }
     }
@@ -85,8 +100,15 @@ safe_VkAccelerationStructureGeometryKHR::safe_VkAccelerationStructureGeometryKHR
     flags = copy_src.flags;
 
     pNext = SafePnextCopy(copy_src.pNext);
-    auto src_iter = as_geom_khr_host_alloc.find(&copy_src);
-    if (src_iter != as_geom_khr_host_alloc.end()) {
+    if (geometryType == VK_GEOMETRY_TYPE_INSTANCES_KHR) {
+        geometry.instances.pNext = SafePnextCopy(copy_src.geometry.instances.pNext);
+    } else if (geometryType == VK_GEOMETRY_TYPE_TRIANGLES_KHR) {
+        geometry.triangles.pNext = SafePnextCopy(copy_src.geometry.triangles.pNext);
+    } else if (geometryType == VK_GEOMETRY_TYPE_AABBS_KHR) {
+        geometry.aabbs.pNext = SafePnextCopy(copy_src.geometry.aabbs.pNext);
+    }
+    auto src_iter = GetAccelStructGeomHostAllocMap().find(&copy_src);
+    if (src_iter != GetAccelStructGeomHostAllocMap().end()) {
         auto& src_alloc = src_iter->second;
         if (geometry.instances.arrayOfPointers) {
             size_t pp_array_size = src_alloc->primitiveCount * sizeof(VkAccelerationStructureInstanceKHR*);
@@ -103,14 +125,14 @@ safe_VkAccelerationStructureGeometryKHR::safe_VkAccelerationStructureGeometryKHR
                 ppInstances[i] = &pInstances[i];
             }
             geometry.instances.data.hostAddress = allocation;
-            as_geom_khr_host_alloc.insert(
+            GetAccelStructGeomHostAllocMap().insert(
                 this, new ASGeomKHRExtraData(allocation, src_alloc->primitiveOffset, src_alloc->primitiveCount));
         } else {
             size_t array_size = src_alloc->primitiveOffset + src_alloc->primitiveCount * sizeof(VkAccelerationStructureInstanceKHR);
             uint8_t* allocation = new uint8_t[array_size];
             memcpy(allocation, src_alloc->ptr, array_size);
             geometry.instances.data.hostAddress = allocation;
-            as_geom_khr_host_alloc.insert(
+            GetAccelStructGeomHostAllocMap().insert(
                 this, new ASGeomKHRExtraData(allocation, src_alloc->primitiveOffset, src_alloc->primitiveCount));
         }
     }
@@ -120,11 +142,18 @@ safe_VkAccelerationStructureGeometryKHR& safe_VkAccelerationStructureGeometryKHR
     const safe_VkAccelerationStructureGeometryKHR& copy_src) {
     if (&copy_src == this) return *this;
 
-    auto iter = as_geom_khr_host_alloc.pop(this);
-    if (iter != as_geom_khr_host_alloc.end()) {
+    auto iter = GetAccelStructGeomHostAllocMap().pop(this);
+    if (iter != GetAccelStructGeomHostAllocMap().end()) {
         delete iter->second;
     }
     FreePnextChain(pNext);
+    if (geometryType == VK_GEOMETRY_TYPE_INSTANCES_KHR) {
+        FreePnextChain(geometry.instances.pNext);
+    } else if (geometryType == VK_GEOMETRY_TYPE_TRIANGLES_KHR) {
+        FreePnextChain(geometry.triangles.pNext);
+    } else if (geometryType == VK_GEOMETRY_TYPE_AABBS_KHR) {
+        FreePnextChain(geometry.aabbs.pNext);
+    }
 
     sType = copy_src.sType;
     geometryType = copy_src.geometryType;
@@ -132,8 +161,15 @@ safe_VkAccelerationStructureGeometryKHR& safe_VkAccelerationStructureGeometryKHR
     flags = copy_src.flags;
 
     pNext = SafePnextCopy(copy_src.pNext);
-    auto src_iter = as_geom_khr_host_alloc.find(&copy_src);
-    if (src_iter != as_geom_khr_host_alloc.end()) {
+    if (geometryType == VK_GEOMETRY_TYPE_INSTANCES_KHR) {
+        geometry.instances.pNext = SafePnextCopy(copy_src.geometry.instances.pNext);
+    } else if (geometryType == VK_GEOMETRY_TYPE_TRIANGLES_KHR) {
+        geometry.triangles.pNext = SafePnextCopy(copy_src.geometry.triangles.pNext);
+    } else if (geometryType == VK_GEOMETRY_TYPE_AABBS_KHR) {
+        geometry.aabbs.pNext = SafePnextCopy(copy_src.geometry.aabbs.pNext);
+    }
+    auto src_iter = GetAccelStructGeomHostAllocMap().find(&copy_src);
+    if (src_iter != GetAccelStructGeomHostAllocMap().end()) {
         auto& src_alloc = src_iter->second;
         if (geometry.instances.arrayOfPointers) {
             size_t pp_array_size = src_alloc->primitiveCount * sizeof(VkAccelerationStructureInstanceKHR*);
@@ -150,14 +186,14 @@ safe_VkAccelerationStructureGeometryKHR& safe_VkAccelerationStructureGeometryKHR
                 ppInstances[i] = &pInstances[i];
             }
             geometry.instances.data.hostAddress = allocation;
-            as_geom_khr_host_alloc.insert(
+            GetAccelStructGeomHostAllocMap().insert(
                 this, new ASGeomKHRExtraData(allocation, src_alloc->primitiveOffset, src_alloc->primitiveCount));
         } else {
             size_t array_size = src_alloc->primitiveOffset + src_alloc->primitiveCount * sizeof(VkAccelerationStructureInstanceKHR);
             uint8_t* allocation = new uint8_t[array_size];
             memcpy(allocation, src_alloc->ptr, array_size);
             geometry.instances.data.hostAddress = allocation;
-            as_geom_khr_host_alloc.insert(
+            GetAccelStructGeomHostAllocMap().insert(
                 this, new ASGeomKHRExtraData(allocation, src_alloc->primitiveOffset, src_alloc->primitiveCount));
         }
     }
@@ -166,21 +202,35 @@ safe_VkAccelerationStructureGeometryKHR& safe_VkAccelerationStructureGeometryKHR
 }
 
 safe_VkAccelerationStructureGeometryKHR::~safe_VkAccelerationStructureGeometryKHR() {
-    auto iter = as_geom_khr_host_alloc.pop(this);
-    if (iter != as_geom_khr_host_alloc.end()) {
+    auto iter = GetAccelStructGeomHostAllocMap().pop(this);
+    if (iter != GetAccelStructGeomHostAllocMap().end()) {
         delete iter->second;
     }
     FreePnextChain(pNext);
+    if (geometryType == VK_GEOMETRY_TYPE_INSTANCES_KHR) {
+        FreePnextChain(geometry.instances.pNext);
+    } else if (geometryType == VK_GEOMETRY_TYPE_TRIANGLES_KHR) {
+        FreePnextChain(geometry.triangles.pNext);
+    } else if (geometryType == VK_GEOMETRY_TYPE_AABBS_KHR) {
+        FreePnextChain(geometry.aabbs.pNext);
+    }
 }
 
 void safe_VkAccelerationStructureGeometryKHR::initialize(const VkAccelerationStructureGeometryKHR* in_struct, const bool is_host,
                                                          const VkAccelerationStructureBuildRangeInfoKHR* build_range_info,
                                                          [[maybe_unused]] PNextCopyState* copy_state) {
-    auto iter = as_geom_khr_host_alloc.pop(this);
-    if (iter != as_geom_khr_host_alloc.end()) {
+    auto iter = GetAccelStructGeomHostAllocMap().pop(this);
+    if (iter != GetAccelStructGeomHostAllocMap().end()) {
         delete iter->second;
     }
     FreePnextChain(pNext);
+    if (geometryType == VK_GEOMETRY_TYPE_INSTANCES_KHR) {
+        FreePnextChain(geometry.instances.pNext);
+    } else if (geometryType == VK_GEOMETRY_TYPE_TRIANGLES_KHR) {
+        FreePnextChain(geometry.triangles.pNext);
+    } else if (geometryType == VK_GEOMETRY_TYPE_AABBS_KHR) {
+        FreePnextChain(geometry.aabbs.pNext);
+    }
     sType = in_struct->sType;
     geometryType = in_struct->geometryType;
     geometry = in_struct->geometry;
@@ -204,7 +254,7 @@ void safe_VkAccelerationStructureGeometryKHR::initialize(const VkAccelerationStr
                 ppInstances[i] = &pInstances[i];
             }
             geometry.instances.data.hostAddress = allocation;
-            as_geom_khr_host_alloc.insert(
+            GetAccelStructGeomHostAllocMap().insert(
                 this, new ASGeomKHRExtraData(allocation, build_range_info->primitiveOffset, build_range_info->primitiveCount));
         } else {
             const auto primitive_offset = build_range_info->primitiveOffset;
@@ -215,7 +265,7 @@ void safe_VkAccelerationStructureGeometryKHR::initialize(const VkAccelerationStr
             memcpy(allocation + primitive_offset, host_address + primitive_offset,
                    primitive_count * sizeof(VkAccelerationStructureInstanceKHR));
             geometry.instances.data.hostAddress = allocation;
-            as_geom_khr_host_alloc.insert(
+            GetAccelStructGeomHostAllocMap().insert(
                 this, new ASGeomKHRExtraData(allocation, build_range_info->primitiveOffset, build_range_info->primitiveCount));
         }
     }
@@ -229,8 +279,15 @@ void safe_VkAccelerationStructureGeometryKHR::initialize(const safe_VkAccelerati
     flags = copy_src->flags;
 
     pNext = SafePnextCopy(copy_src->pNext);
-    auto src_iter = as_geom_khr_host_alloc.find(copy_src);
-    if (src_iter != as_geom_khr_host_alloc.end()) {
+    if (geometryType == VK_GEOMETRY_TYPE_INSTANCES_KHR) {
+        geometry.instances.pNext = SafePnextCopy(copy_src->geometry.instances.pNext, copy_state);
+    } else if (geometryType == VK_GEOMETRY_TYPE_TRIANGLES_KHR) {
+        geometry.triangles.pNext = SafePnextCopy(copy_src->geometry.triangles.pNext, copy_state);
+    } else if (geometryType == VK_GEOMETRY_TYPE_AABBS_KHR) {
+        geometry.aabbs.pNext = SafePnextCopy(copy_src->geometry.aabbs.pNext, copy_state);
+    }
+    auto src_iter = GetAccelStructGeomHostAllocMap().find(copy_src);
+    if (src_iter != GetAccelStructGeomHostAllocMap().end()) {
         auto& src_alloc = src_iter->second;
         if (geometry.instances.arrayOfPointers) {
             size_t pp_array_size = src_alloc->primitiveCount * sizeof(VkAccelerationStructureInstanceKHR*);
@@ -247,14 +304,14 @@ void safe_VkAccelerationStructureGeometryKHR::initialize(const safe_VkAccelerati
                 ppInstances[i] = &pInstances[i];
             }
             geometry.instances.data.hostAddress = allocation;
-            as_geom_khr_host_alloc.insert(
+            GetAccelStructGeomHostAllocMap().insert(
                 this, new ASGeomKHRExtraData(allocation, src_alloc->primitiveOffset, src_alloc->primitiveCount));
         } else {
             size_t array_size = src_alloc->primitiveOffset + src_alloc->primitiveCount * sizeof(VkAccelerationStructureInstanceKHR);
             uint8_t* allocation = new uint8_t[array_size];
             memcpy(allocation, src_alloc->ptr, array_size);
             geometry.instances.data.hostAddress = allocation;
-            as_geom_khr_host_alloc.insert(
+            GetAccelStructGeomHostAllocMap().insert(
                 this, new ASGeomKHRExtraData(allocation, src_alloc->primitiveOffset, src_alloc->primitiveCount));
         }
     }
